Django Podcasting
=================

Django Podcasting is a reusable application which provides audio
podcasting functionality for websites running on the Django Web
framework.

More documentation about the usage and installation of Django Podcasting
can be found on `django-podcasting.readthedocs.org`_.

The source code for Django Podcasting can be found and contributed to on
`github.com/rizumu/django-podcasting`_. There you can also `file issues`_.

To find out what's new in this version of django-podcasting, please see 
`the changelog`_

The `in-development version`_ of Django Podcasting can be installed with::

    pip install django-podcasting==dev

.. _github.com/rizumu/django-podcasting: https://github.com/rizumu/django-podcasting/
.. _django-podcasting.readthedocs.org: http://django-podcasting.readthedocs.org/
.. _file issues: https://github.com/rizumu/django-podcasting/issues/
.. _in-development version: https://github.com/rizumu/django-podcasting/tarball/master#egg=django-podcasting-dev
.. _the changelog: http://django-podcasting.readthedocs.org/en/latest/changelog.html
